@@ -326,7 +326,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, GList *folders)
 
 			for (l = folders; l != NULL; l=l->next)
 			{
-				char *title;
+				const char *title;
 				
 				title = l->data ? (char *) l->data : "";
 				
@@ -777,6 +777,9 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 			g_free (parsedname);
 
 			break;
+                case NS_NOTES:
+                case NS_SEPARATOR:
+                case NS_UNKNOWN:
 		default:
 			break;
 		}
@@ -824,7 +827,7 @@ parse_rdf_lang_tag (xmlNode  *child,
 		    int      *best_match)
 {
 	const char * const *locales;
-	char *this_language;
+	const char *this_language;
 	xmlChar *lang;
 	xmlChar *content;
 	int i;
